/*
 * extra constants for use by the plugin
 */

#define TRACE_NONE	0x00
#define TRACE_CALL	0x01
#define TRACE_TYPE	0x11
#define TRACE_NAME	0x21
#define TRACE_DESC	0x41
#define TRACE_ALL	0xff

/* defs missing from libgimp */

#define BEHIND_MODE	2

#define FG_BG_RGB 0
#define FG_BG_HSV 1
#define FG_TRANS 2
#define CUSTOM 3

#define LINEAR 0
#define BILINEAR 1
#define RADIAL 2
#define SQUARE 3
#define CONICAL_SYMMETRIC 4
#define CONICAL_ASYMMETRIC 5
#define SHAPEBURST_ANGULAR 6
#define SHAPEBURST_SPHERICAL 7
#define SHAPEBURST_DIMPLED 8

#define REPEAT_NONE 0
#define REPEAT_SAWTOOTH 1
#define REPEAT_TRIANGULAR 2

#define FG_BUCKET_FILL 0
#define BG_BUCKET_FILL 1
#define PATTERN_BUCKET_FILL 2

#define BG_IMAGE_FILL 0
#define WHITE_IMAGE_FILL 1
#define TRANS_IMAGE_FILL 2
#define NO_IMAGE_FILL 3

#define RED_CHANNEL 0
#define GREEN_CHANNEL 1
#define BLUE_CHANNEL 2
#define GRAY_CHANNEL 3
#define INDEXED_CHANNEL 4

#define WHITE_MASK 0
#define BLACK_MASK 1
#define ALPHA_MASK 2

#define APPLY 0
#define DISCARD 1

#define EXPAND_AS_NECESSARY 0
#define CLIP_TO_IMAGE 1
#define CLIP_TO_BOTTOM_LAYER 2

#define SELECTION_ADD 0
#define SELECTION_SUB 1
#define SELECTION_REPLACE 2
#define SELECTION_INTERSECT 3

#define PIXELS 0
#define POINTS 1

#define IMAGE_CLONE 0
#define PATTERN_CLONE 1

#define BLUR 0
#define SHARPEN 1

/*
#define TRUE 1
#define FALSE 0
*/

